@@ -262,7 +262,7 @@ recompile_resolver(Mods, ResolverMod) ->
 			       [io_lib:format("'~s'", [RecName]) |
 				["_" || _ <- lists:seq(1, RecSize)]],
 			       ","), M])
-		  end, Records) ++ ["lookup(_) -> undefined."],
+		  end, Records) ++ ["lookup(Term) -> erlang:error(badarg, [Term])."],
 		";" ++ io_lib:nl()),
     Lookup2 = string:join(
 		lists:map(
@@ -464,7 +464,7 @@ write_resolver(_TaggedElems, ParentMod, ErlDirName, SpecFile) ->
     Compile = erl_syntax:attribute(?AST(compile), [?AST(export_all)]),
     AST = [make_function(modules, [], [?AST([])]),
 	   make_function(lookup, [?AST(_), ?AST(_)], [?AST(undefined)]),
-	   make_function(lookup, [?AST(_)], [?AST(undefined)])],
+	   make_function(lookup, [?AST(Term)], [?AST(erlang:error(badarg, [Term]))])],
     ResultAST = erl_syntax:form_list([Hdr, Module, Compile|AST]),
     file:write_file(
       filename:join([ErlDirName, ModNameErl]),
@@ -965,15 +965,15 @@ make_printer(TaggedSpecs, PredefRecords, ModName, ParentMod) ->
 		 erl_syntax:clause(
 		   [?AST(Name), ?AST(Arity)],
 		   none,
-		   [erl_syntax:case_expr(
-		      ?AST(get_mod(
-			     erlang:make_tuple(Arity+1, undefined, [{1, Name}]))),
+		   [erl_syntax:try_expr(
+		      [?AST(get_mod(
+			      erlang:make_tuple(Arity+1, undefined, [{1, Name}])))],
 		      [erl_syntax:clause(
-			 [?AST(undefined)], none, [?AST(no)]),
-		       erl_syntax:clause(
 			 [?AST(Mod)],
 			 none,
-			 [?AST(Mod:pp(Name, Arity))])])])];
+			 [?AST(Mod:pp(Name, Arity))])],
+		      [erl_syntax:clause(
+			 [?AST(error:badarg)], none, [?AST(no)])])])];
 	   true ->
 		[erl_syntax:clause([?AST(_), ?AST(_)], none, [?AST(no)])]
 	end,
@@ -2563,7 +2563,7 @@ consult(Path) ->
             {Terms, OtherForms} =
                 lists:foldl(
                   fun([Form], {Trms, Other}) ->
-                          Trm = 
+                          Trm =
                               erl_syntax_lib:map(
                                 fun(T) ->
                                         case erl_syntax:type(T) of
